@@ -18,9 +18,9 @@ impl Visit for ImportFinder {
         e.visit_children_with(self);
 
         match &e.callee {
-            ExprOrSuper::Expr(callee) => match &**callee {
+            Callee::Expr(callee) => match &**callee {
                 Expr::Ident(i) => {
-                    if &*i.sym == "require" || &*i.sym == "import" {
+                    if &*i.sym == "require" {
                         self.found = true;
                     }
                 }
@@ -28,6 +28,8 @@ impl Visit for ImportFinder {
                 _ => {}
             },
 
+            Callee::Import(_) => self.found = true,
+
             _ => {}
         }
     }
