@@ -90,7 +90,7 @@ impl VisitMut for AssertValid {
 }
 
 #[testing::fixture("../swc_ecma_parser/tests/typescript/**/input.ts")]
-#[testing::fixture("../swc/tests/tsc-references/**/output.js")]
+#[testing::fixture("../swc/tests/tsc-references/**/*.js")]
 fn assert_no_invalid(input: PathBuf) {
     testing::run_test(false, |cm, _handler| {
         let fm = cm.load_file(&input).unwrap();
